

matcher
~~~~~~~

.. toctree::
   :caption: Matcher

   matcher/BaseMatcher
   matcher/SimpleMatcher
   matcher/DistanceMatcher

.. toctree::
   :caption: Matching

   matcher/BaseMatching



map
~~~

.. toctree::
   :caption: Map

   map/BaseMap
   map/InMemMap
   map/SqliteMap



util
~~~~

.. toctree::
   :caption: Util

   util/Segment
